get_mkv_info: Get informations about subtitles embedded in MKV files

View source: R/read_mkv.R

get_mkv_infoR Documentation

Get informations about subtitles embedded in MKV files

Description

This function uses mkvmerge to extract tracks data from an MKV file. You must have mkvmerge installed on your computer.

Usage

get_mkv_info(file, mkvmerge.exec = "mkvmerge", print.info = TRUE)

Arguments

file

a character string giving the path to the MKV file.

mkvmerge.exec

a character string giving the path to the mkvmerge executable.

print.info

print basic informations about subtitle tracks. Default is TRUE.

Value

A list with complete data about the MKV is invisibly returned. If the MKV has at least 1 subtitles track and print.info is TRUE, basic informations are printed. Otherwise it returns a warning.

References

https://mkvtoolnix.download/downloads.html


subtools documentation built on March 24, 2026, 5:07 p.m.