move_subtitles: Move subtitles Move subtitles forward or backward in...

View source: R/move_subtitles.R

move_subtitlesR Documentation

Move subtitles Move subtitles forward or backward in subtitles.

Description

Move subtitles Move subtitles forward or backward in subtitles.

Usage

move_subtitles(x, lag)

Arguments

x

subtitles or multisubtitles objects to be moved.

lag

numeric. Number of seconds the subtitles should be moved, forward if positive and backward if negative.

Value

A subtitles or multisubtitles object.

Examples

  f1 <- system.file("extdata", "ex_subrip.srt", package = "subtools")
  s1 <- read_subtitles(f1, metadata = tibble::tibble(Season = 1, Episode = 2))
  s2 <- move_subtitles(s1, 2.7)

subtools documentation built on March 24, 2026, 5:07 p.m.