read_subtitles_mkv: Extract subtitles embedded in MKV files

View source: R/read_mkv.R

read_subtitles_mkvR Documentation

Extract subtitles embedded in MKV files

Description

This function uses mkvextract to extract subtitles from an MKV file. You must have mkvmerge and mkvextract installed on your computer.

Usage

read_subtitles_mkv(
  file,
  id = 2,
  mkvextract.exec = "mkvextract",
  mkvmerge.exec = "mkvmerge"
)

Arguments

file

a character string giving the path to the MKV file.

id

An integer giving the ID of the tracks to be extracted. Can be a vector of length > 1 to extract several tracks. If NA (default), the default subtitle tracks will be extracted

mkvextract.exec

a character string giving the path to the mkvextract executable.

mkvmerge.exec

character string giving the path to the mkvmerge executable.

Details

The function get_mkv_info is a simple way to identify the ID of subtitles tracks from a MKV file.

Not all the subtitle formats supported by mkvextract can be read by subtools. See read_subtitles for the list of formats currently supported.

Value

An object of class subtitles (see subtitles). If several tracks are requested (via id), an object of class multisubtitles; i.e. a list of subtitles objects.

References

https://mkvtoolnix.download/downloads.html


subtools documentation built on March 24, 2026, 5:07 p.m.