| get_mkv_info | R Documentation |
This function uses mkvmerge to extract tracks data from an MKV file.
You must have mkvmerge installed on your computer.
get_mkv_info(file, mkvmerge.exec = "mkvmerge", print.info = TRUE)
file |
a character string giving the path to the MKV file. |
mkvmerge.exec |
a character string giving the path to the |
print.info |
print basic informations about subtitle tracks. Default is |
A list with complete data about the MKV is invisibly returned.
If the MKV has at least 1 subtitles track and print.info is TRUE, basic informations are printed.
Otherwise it returns a warning.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.