| read_subtitles_mkv | R Documentation |
This function uses mkvextract to extract subtitles from an MKV file.
You must have mkvmerge and mkvextract installed on your computer.
read_subtitles_mkv(
file,
id = 2,
mkvextract.exec = "mkvextract",
mkvmerge.exec = "mkvmerge"
)
file |
a character string giving the path to the MKV file. |
id |
An integer giving the ID of the tracks to be extracted.
Can be a vector of length > 1 to extract several tracks.
If |
mkvextract.exec |
a character string giving the path to the |
mkvmerge.exec |
character string giving the path to the |
The function get_mkv_info is a simple way to identify the ID of subtitles tracks from a MKV file.
Not all the subtitle formats supported by mkvextract can be read by subtools.
See read_subtitles for the list of formats currently supported.
An object of class subtitles (see subtitles).
If several tracks are requested (via id), an object of class multisubtitles;
i.e. a list of subtitles objects.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.